@@ -8,8 +8,7 @@
 
 #include "todoviewview.h"
 
-#include <CalendarSupport/KDatePickerPopup>
-
+#include <KDatePickerPopup>
 #include <KLocalizedString>
 #include <QMenu>
 
@@ -30,9 +29,7 @@ TodoViewView::TodoViewView(QWidget *parent)
     connect(&mExpandTimer, &QTimer::timeout, this, &TodoViewView::expandParent);
     mExpandTimer.setInterval(1s);
     header()->setStretchLastSection(false);
-    mStartPopupMenu = new CalendarSupport::KDatePickerPopup(
-        CalendarSupport::KDatePickerPopup::NoDate | CalendarSupport::KDatePickerPopup::DatePicker | CalendarSupport::KDatePickerPopup::Words,
-        QDate::currentDate(), this);
+    mStartPopupMenu = new KDatePickerPopup(KDatePickerPopup::NoDate | KDatePickerPopup::DatePicker | KDatePickerPopup::Words, QDate::currentDate(), this);
 }
 
 bool TodoViewView::isEditing(const QModelIndex &index) const
@@ -72,7 +69,7 @@ bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
     return false;
 }
 
-CalendarSupport::KDatePickerPopup *TodoViewView::startPopupMenu()
+KDatePickerPopup *TodoViewView::startPopupMenu()
 {
     return mStartPopupMenu;
 }
