@@ -18,11 +18,11 @@
 #include "timeline/timelineview.h"
 #include <CalendarSupport/CollectionSelection>
 
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 #include <KCalendarCore/Event>
 
-#include <AkonadiCore/Collection>
-#include <AkonadiWidgets/ControlGui>
+#include <Akonadi/Collection>
+#include <Akonadi/ControlGui>
 
 #include <KCheckableProxyModel>
 
@@ -102,7 +102,7 @@ void MainWindow::delayedInit()
     mIncidenceChanger = new IncidenceChanger(this);
     mCalendar->setCollectionFilteringEnabled(false);
 
-    Q_FOREACH (const QString &viewName, mViewNames) {
+    for (const QString &viewName : std::as_const(mViewNames)) {
         addView(viewName);
     }
 }
