@@ -5,29 +5,34 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARVIEWS_WHATSNEXTVIEW_H
-#define CALENDARVIEWS_WHATSNEXTVIEW_H
+#pragma once
 
 #include "eventview.h"
 
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 
 #include <KIconLoader>
 
-#include <QUrl>
 #include <QTextBrowser>
+#include <QUrl>
 
-namespace EventViews {
+namespace EventViews
+{
 class WhatsNextTextBrowser : public QTextBrowser
 {
     Q_OBJECT
 public:
-    explicit WhatsNextTextBrowser(QWidget *parent) : QTextBrowser(parent)
+    explicit WhatsNextTextBrowser(QWidget *parent)
+        : QTextBrowser(parent)
     {
     }
 
     /** Reimplemented from QTextBrowser to handle links. */
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void setSource(const QUrl &name) override;
+#else
+    void doSetSource(const QUrl &name, QTextDocument::ResourceType type = QTextDocument::UnknownResource) override;
+#endif
 
 Q_SIGNALS:
     void showIncidence(const QString &uid);
@@ -46,12 +51,12 @@ public:
     Q_REQUIRED_RESULT int currentDateCount() const override;
     Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override
     {
-        return Akonadi::Item::List();
+        return {};
     }
 
     Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override
     {
-        return KCalendarCore::DateList();
+        return {};
     }
 
     Q_REQUIRED_RESULT bool supportsDateNavigation() const
@@ -71,11 +76,11 @@ protected:
     void appendTodo(const KCalendarCore::Incidence::Ptr &);
 
 private Q_SLOTS:
-    void showIncidence(const QString &);
+    EVENTVIEWS_NO_EXPORT void showIncidence(const QString &);
 
 private:
-    void createTaskRow(KIconLoader *kil);
-    WhatsNextTextBrowser *mView = nullptr;
+    EVENTVIEWS_NO_EXPORT void createTaskRow(KIconLoader *kil);
+    WhatsNextTextBrowser *const mView;
     QString mText;
     QDate mStartDate;
     QDate mEndDate;
@@ -83,5 +88,3 @@ private:
     Akonadi::Item::List mTodos;
 };
 }
-
-#endif
